# ROXIE_3ML

3ML is a versatile application providing a graphical user interface (GUI) for users to interact with Magnets database, view reports of models and systems, upload files, and load ROXIE models directly from the database. In order to run the application just type "roxie_3ml" in the terminal and the GUI will launch.

## License

This project is licensed under the GPL-3.0-or-later license. It uses PyQt6, which is also GPL-licensed.

### Third-Party Licenses

This project uses [Feather icons](https://feathericons.com/), which are licensed under the MIT License. See `LICENSES/LicenseRef-feather-MIT.txt` for details.
